package com.qs.mp.web.controller.api.admin;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.qs.mp.admin.domain.*;
import com.qs.mp.admin.domain.excel.MarketingHitPrizeExcel;
import com.qs.mp.admin.domain.param.*;
import com.qs.mp.admin.domain.vo.*;
import com.qs.mp.admin.service.*;
import com.qs.mp.common.annotation.Log;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.common.enums.BusinessType;
import com.qs.mp.common.enums.GroupBuyingStatusEnum;
import com.qs.mp.common.enums.MarketingStatusEnum;
import com.qs.mp.common.enums.UserTypeEnum;
import com.qs.mp.user.domain.MarketingHitPrize;
import com.qs.mp.user.domain.MarketingUserCode;
import com.qs.mp.user.service.IGroupBuyingHitPrizeService;
import com.qs.mp.utils.ExcelUtil;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;


/**
 * @ClassName GroupBuyingMgrController
 * @author yang.zhao
 * @date 2023.9.20
 * @time 18:09
 * @Version 1.0
 * @Description
 */
@RestController
@RequestMapping("/api/v1/mp/admin/groupbuying")
@Api(tags = "拼团活动管理相关接口")
public class GroupBuyingMgrController extends BaseApiController {

    //拼团活动
    @Autowired
    private IGroupBuyingService groupBuyingService;

    //拼团活动拼团
    @Autowired
    private IGroupBuyingGroupService groupBuyingGroupService;

    //拼团活动奖项
    @Autowired
    private IGroupBuyingAwardsService groupBuyingAwardsService;

    //拼团活动奖项对应奖品
    @Autowired
    private IGroupBuyingAwardsPrizeService groupBuyingAwardsPrizeService;


    /**
     * 复制拼团抽奖活动
     * @param groupBuyingId
     * @return
     */
    @PreAuthorize("@ss.hasPermi('business:groupbuying:copy')")
    @PostMapping("/copy/{groupBuyingId}")
    @ApiOperation("拷贝拼团抽奖活动")
    public AjaxResult copy(@PathVariable("groupBuyingId") Long groupBuyingId) {

        groupBuyingService.copyById(groupBuyingId);

        return AjaxResult.success();
    }

    /**
     * 创建拼团抽奖活动
     * @param groupBuyingCreateParam
     * @return
     */
    @Log(title = "拼团活动新增", businessType = BusinessType.INSERT)
    @ApiOperation(value = "拼团活动新增")
    @PostMapping("/create")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:add')")
    public AjaxResult create(@Validated @RequestBody GroupBuyingCreateParam groupBuyingCreateParam) {
        groupBuyingService.createGroupBuying(groupBuyingCreateParam);
        return AjaxResult.success();
    }

    /**
     * 拼团抽奖活动编辑更新
     * @param groupBuyingUpdateParam
     * @return
     */
    @PostMapping("/update")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:edit')")
    @ApiOperation("修改拼团活动")
    public AjaxResult update(@Validated @RequestBody GroupBuyingUpdateParam groupBuyingUpdateParam) {
        groupBuyingService.updateGroupBuying(groupBuyingUpdateParam);
        return AjaxResult.success();
    }

    /**
     * 拼团活动列表
     * @param groupBuyingQueryParam
     * @return
     */
    @PostMapping("/list")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:list')")
    @ApiOperation("拼团活动列表")
    @ApiResponses(
            @ApiResponse(code = 200, message = "拼团活动列表", response = GroupBuyingListVO.class)
    )
    public TableDataInfo list(@RequestBody GroupBuyingQueryParam groupBuyingQueryParam) {
        startPage();
        List<GroupBuying> groupBuyingList = groupBuyingService.listGroupBuying(groupBuyingQueryParam);
        List<GroupBuyingListVO> groupBuyingListVOS = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(groupBuyingList)) {
            groupBuyingListVOS = groupBuyingList.stream().map(groupBuying -> {
                GroupBuyingListVO groupBuyingListVO = new GroupBuyingListVO();
                BeanUtils.copyProperties(groupBuying, groupBuyingListVO);
                return groupBuyingListVO;
            }).collect(Collectors.toList());
        }
        TableDataInfo res = getDataTable(groupBuyingList);
        res.setRows(groupBuyingListVOS);

        return res;
    }


    /**
     * 查看拼团活动详情
     * @param id
     * @return
     */
    @PostMapping("/detail/{id}")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:query')")
    @ApiOperation("活动详情")
    @ApiResponses(
            @ApiResponse(code = 200, message = "活动详情", response = GroupBuyingVO.class)
    )
    public AjaxResult detail(@PathVariable("id") Long id) {
        GroupBuyingVO groupBuyingVO = new GroupBuyingVO();
        GroupBuying groupBuying = groupBuyingService.getById(id);
        if (Objects.isNull(groupBuying)) {
            return AjaxResult.error("活动信息不存在");
        }
        BeanUtils.copyProperties(groupBuying, groupBuyingVO);

        // 获取奖级信息
        List<GroupBuyingAwards> groupBuyingAwardsList = groupBuyingAwardsService.list(new LambdaQueryWrapper<GroupBuyingAwards>()
                .eq(GroupBuyingAwards::getGroupbuyingId, id)
                .orderByAsc(GroupBuyingAwards::getSort));

        List<GroupBuyingAwardsVO> groupBuyingAwardsVOS = groupBuyingAwardsList.stream().map(groupBuyingAwards -> {
            GroupBuyingAwardsVO groupBuyingAwardsVO = new GroupBuyingAwardsVO();
            BeanUtils.copyProperties(groupBuyingAwards, groupBuyingAwardsVO);
            List<GroupBuyingAwardsPrize> groupBuyingAwardsPrizeList = groupBuyingAwardsPrizeService.listPrizeVO(new LambdaQueryWrapper<GroupBuyingAwardsPrize>()
                    .eq(GroupBuyingAwardsPrize::getAwardsId, groupBuyingAwards.getId()));
            groupBuyingAwardsVO.setPrizeList(groupBuyingAwardsPrizeList);
            return groupBuyingAwardsVO;
        }).collect(Collectors.toList());

        groupBuyingVO.setAwardsList(groupBuyingAwardsVOS);

        return AjaxResult.success(groupBuyingVO);
    }

    /**
     * 拼团活动上架
     * @param id
     * @return
     */
    @PostMapping("/up/{id}")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:up')")
    @ApiOperation("拼团活动上架")
    public AjaxResult up(@PathVariable("id") Long id) {
        GroupBuying groupBuying = groupBuyingService.getById(id);
        if (Objects.isNull(groupBuying)) {
            return AjaxResult.error("活动信息不存在");
        }
        if (GroupBuyingStatusEnum.END.getValue().equals(groupBuying.getIsPutaway()) || groupBuying.getEndTime().compareTo(new Date()) < 0) {
            return AjaxResult.error("已关闭的活动不支持上架");
        }

        if (GroupBuyingStatusEnum.UP.getValue().equals(groupBuying.getIsPutaway())) {
            return AjaxResult.error("频繁操作,请刷新后重试");
        }

        // 开启活动
        groupBuyingService.update(new LambdaUpdateWrapper<GroupBuying>()
                .set(GroupBuying::getIsPutaway, GroupBuyingStatusEnum.UP.getValue())
                .eq(GroupBuying::getId, id));

        return AjaxResult.success();
    }


    /**
     * 拼团活动下架
     * @param id
     * @return
     */
    @PostMapping("/down/{id}")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:down')")
    @ApiOperation("下架活动")
    public AjaxResult down(@PathVariable("id") Long id) {
        GroupBuying groupBuying = groupBuyingService.getById(id);
        if (Objects.isNull(groupBuying)) {
            return AjaxResult.error("活动信息不存在");
        }
        if (MarketingStatusEnum.CLOSE.getValue().equals(groupBuying.getIsPutaway())) {
            return AjaxResult.error("频繁操作,请刷新后重试");
        }

        //查询当前活动下的拼团信息，如果有未成团的团，修改团的状态并退款


        // 下架活动
        groupBuyingService.update(new LambdaUpdateWrapper<GroupBuying>()
                .set(GroupBuying::getIsPutaway, GroupBuyingStatusEnum.DOWN.getValue())
                .eq(GroupBuying::getId, id));

        return AjaxResult.success();
    }


    /**
     * 拼团活动数据
     * @param groupBuyingDataQueryParam
     * @return
     */
    @PostMapping("/data/{id}")
    @PreAuthorize("@ss.hasPermi('business:groupbuying:queryData')")
    @ApiOperation("活动数据")
    @ApiResponses(
            @ApiResponse(code = 200, message = "success", response = GroupBuyingDataVO.class)
    )
    public AjaxResult dataInfo(@RequestBody GroupBuyingDataQueryParam groupBuyingDataQueryParam) {
        GroupBuyingDataVO groupBuyingDataVO = new GroupBuyingDataVO();
        GroupBuying groupBuying = groupBuyingService.getById(groupBuyingDataQueryParam.getId());
        if (Objects.isNull(groupBuying)) {
            return AjaxResult.error("活动信息不存在");
        }

        groupBuyingDataVO.setTitle(groupBuying.getTitle());
        groupBuyingDataVO.setGroupPrice(groupBuying.getGroupPrice());
        groupBuyingDataVO.setGroupSize(groupBuyingDataVO.getGroupSize());

        //查询活动对应的团列表
        List<GroupBuyingGroupDataVO> groupBuyingGroupDataVOS = new ArrayList<>();
        List<GroupBuyingGroup> groupBuyingGroups = groupBuyingGroupService.list(new LambdaQueryWrapper<GroupBuyingGroup>()
                .eq(GroupBuyingGroup::getGroupbuyingId, groupBuyingDataQueryParam.getId())
                .eq(null != groupBuyingDataQueryParam.getStatus(), GroupBuyingGroup::getGroupStatus, groupBuyingDataQueryParam.getStatus())
                .eq(null != groupBuyingDataQueryParam.getMobile() && StringUtils.isNotBlank(groupBuyingDataQueryParam.getMobile()), GroupBuyingGroup::getStartGroupUserMobile, groupBuyingDataQueryParam.getMobile())
                .orderByAsc(GroupBuyingGroup::getCreateTime));
        if (CollectionUtils.isNotEmpty(groupBuyingGroups)){
            groupBuyingGroupDataVOS = groupBuyingGroups.stream().map(groupBuyingGroup -> {
                GroupBuyingGroupDataVO groupBuyingGroupDataVO = new GroupBuyingGroupDataVO();
                BeanUtils.copyProperties(groupBuyingGroup, groupBuyingGroupDataVO);
                return groupBuyingGroupDataVO;
            }).collect(Collectors.toList());
        }

        groupBuyingDataVO.setGroupList(groupBuyingGroupDataVOS);


        return AjaxResult.success(groupBuyingDataVO);
    }


}
