package com.qs.mp.web.controller.api.admin;

import com.qs.mp.admin.domain.param.*;
import com.qs.mp.admin.domain.vo.GroupBuyingOrder;
import com.qs.mp.common.annotation.Log;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.common.enums.*;
import com.qs.mp.user.service.IGroupBuyingHitPrizeService;
import com.qs.mp.user.service.IGroupBuyingOrderService;
import com.qs.mp.web.controller.common.BaseApiController;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.AllArgsConstructor;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;

/**
 * @ClassName GroupBuyingOrderMgrController
 * @author yang.zhao
 * @date 2023.9.23
 * @time 17:37
 * @Version 1.0
 * @Description
 */
@RestController
@RequestMapping("/api/v1/mp/admin/groupbuying/order")
@Api(tags = "拼团抽奖订单管理接口")
@AllArgsConstructor
public class GroupBuyingOrderMgrController extends BaseApiController {

	@Autowired
	private IGroupBuyingOrderService groupBuyingOrderService;

	@Autowired
	private IGroupBuyingHitPrizeService groupBuyingHitPrizeService;




	/**
	 * 拼团活动中奖订单列表
	 * @param groupBuyingOrderParam
	 * @return
	 */
	@PostMapping("/list")
	@ApiOperation(value = "拼团抽奖订单列表" , notes = "获取所有订单信息")
	@PreAuthorize("@ss.hasPermi('order:groupbuying:list')")
	@ApiResponses(
			@ApiResponse(code = 200, message = "success", response = Map.class)
	)
	public TableDataInfo list(@RequestBody GroupBuyingOrderParam groupBuyingOrderParam) {
		//开启分页
		startPage();
		//查询用户中奖信息记录
		List<GroupBuyingOrder> userOrderRecords = groupBuyingOrderService.selectUserOrder(groupBuyingOrderParam);
		return getDataTable(userOrderRecords);
	}


	@PostMapping("/order/cancel")
	@PreAuthorize("@ss.hasPermi('order:groupbuying:cancel')")
	@ApiOperation("经销商订单取消")
	public AjaxResult cancelOrder(@RequestBody GroupBuyingOrderParam groupBuyingOrderParam) {
		if (Objects.isNull(groupBuyingOrderParam)){
			return AjaxResult.error("缺少请求参数！");
		}
		return AjaxResult.success(groupBuyingOrderService.cancelOrderByAdmin(groupBuyingOrderParam));
	}



  /**
   * 订单发货
   */
  @Log(title = "经销商订单发货", businessType = BusinessType.UPDATE)
  @PostMapping("/ship")
  @ApiOperation(value = "订单发货" , notes = "在订单发货页面提交")
  @ApiResponses(
		  @ApiResponse(code = 200, message = "操作成功", response = AjaxResult.class)
  )
  @PreAuthorize("@ss.hasPermi('order:groupbuying:ship')")
  public AjaxResult ship(@RequestBody GroupBuyingOrderParam groupBuyingOrderParam) {
		if(null == groupBuyingOrderParam || StringUtils.isBlank(groupBuyingOrderParam.getOrderId())) {
			return error(ErrorCodeEnum.ERROR_CODE_1001);
		}

		//查询订单记录
	  	GroupBuyingOrder orderRecord = groupBuyingOrderService.getById(groupBuyingOrderParam.getOrderId());
		if(null == orderRecord || StringUtils.isBlank(orderRecord.getOrderId())
				|| null == orderRecord.getChannelId()) {
			return error(ErrorCodeEnum.ERROR_CODE_1001);
		}
		Integer deliveryType = groupBuyingOrderParam.getDeliveryType();
	  if (DeliverTypeEnum.DELIVER.getValue().equals(deliveryType)) {
		  if (Objects.isNull(groupBuyingOrderParam.getDeliveryId())) {
			  return AjaxResult.error("快递公司不能为空");
		  }
		  if (StringUtils.isBlank(groupBuyingOrderParam.getDeliveryFlowId())) {
			  return AjaxResult.error("快递单号不能为空");
		  }
	  }

		GroupBuyingOrder groupBuyingOrder = new GroupBuyingOrder();
		groupBuyingOrder.setOrderId(groupBuyingOrderParam.getOrderId());
		if (DeliverTypeEnum.NO_DELIVER.getValue().equals(deliveryType)) {
			// 无需物流，设置发货时间为当前时间
			groupBuyingOrder.setStatus(2);
			groupBuyingOrder.setDeliveryTime(new Date());

		} else if (DeliverTypeEnum.DELIVER.getValue().equals(deliveryType)) {
			// 快递发货，设置物流信息
			groupBuyingOrder.setStatus(2);
			groupBuyingOrder.setDeliveryId(groupBuyingOrderParam.getDeliveryId());
			groupBuyingOrder.setDeliveryFlowId(groupBuyingOrderParam.getDeliveryFlowId());
			groupBuyingOrder.setDeliveryTime(new Date());
		}

		//更新订单
	  boolean rtn = groupBuyingOrderService.updateById(groupBuyingOrder);

	  return rtn ? AjaxResult.success() : AjaxResult.error("发货失败");
  }


}
