package com.qs.mp.common.enums;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.annotation.IEnum;
import com.qs.mp.common.utils.DateUtils;
import io.swagger.annotations.ApiModel;

import java.util.Date;

/**
 * 拼团活动状态枚举类
 * @author yang.zhao
 */
@ApiModel("拼团活动状态枚举类")
public enum GroupBuyingStatusEnum implements IEnum<Integer> {

    UP(0, "上架"),

    DOWN(1,"下架"),

    END(2,"已结束"),

    UNDERWAY(3,"进行中"),

    WARMUP(4,"预热中"),

    COMPLETED(5,"已完成");

    private Integer value;
    private String desc;

    GroupBuyingStatusEnum(Integer value, String desc) {
        this.value = value;
        this.desc = desc;
    }

    @Override
    public Integer getValue() {
        return value;
    }

    public String getDesc() {
        return desc;
    }


    /**
     * 重写toString，单个转化成json
     * @return
     */
    @Override
    public String toString() {
        JSONObject object = new JSONObject();
        object.put("value",value);
        object.put("desc", desc);
        return object.toString();
    }

    public static GroupBuyingStatusEnum getByValue(Integer value) {
        for (GroupBuyingStatusEnum statusEnum : GroupBuyingStatusEnum.values()) {
            if (statusEnum.getValue().equals(value)) {
                return statusEnum;
            }
        }
        return null;
    }


    /**
     * 根据活动是否上架，通过开始结束时间判断活动状态
     * @param startTime
     * @param endTime
     * @param isPutaway
     * @return
     */
    public static String getStatus(Date startTime, Date endTime, Integer isPutaway) {
        //活动已下架
        if (GroupBuyingStatusEnum.DOWN.getValue().equals(isPutaway)) {
            return GroupBuyingStatusEnum.DOWN.toString();
        }
        //活动已结束
        if (GroupBuyingStatusEnum.END.getValue().equals(isPutaway)) {
            return GroupBuyingStatusEnum.END.toString();
        }

        Date now = DateUtils.getNowDate();
        if (now.before(startTime)) {
            //活动预热中
            return GroupBuyingStatusEnum.WARMUP.toString();
        }else if (now.after(endTime)) {
            //活动已结束
            return GroupBuyingStatusEnum.END.toString();
        }else {
            //活动进行中
            return GroupBuyingStatusEnum.UNDERWAY.toString();
        }

    }
}
