package com.qs.mp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qs.mp.admin.domain.excel.MarketingHitPrizeExcel;
import com.qs.mp.admin.domain.param.GroupBuyingOrderParam;
import com.qs.mp.admin.domain.vo.GroupBuyingOrder;
import com.qs.mp.common.enums.ChannelOrderStatusEnum;
import com.qs.mp.common.exception.ServiceException;
import com.qs.mp.pay.service.IWalletService;
import com.qs.mp.user.domain.MarketingHitPrize;
import com.qs.mp.user.domain.vo.UserMarketingHitPrizeListVO;
import com.qs.mp.user.mapper.GroupBuyingHitPrizeMapper;
import com.qs.mp.user.mapper.GroupBuyingOrderMapper;
import com.qs.mp.user.service.IGroupBuyingOrderService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 营销活动订单信息表 服务实现类
 * </p>
 *
 * @author yang.zhao
 */
@Service
public class GroupBuyingOrderServiceImpl extends ServiceImpl<GroupBuyingOrderMapper, GroupBuyingOrder> implements IGroupBuyingOrderService {

    @Autowired
    private GroupBuyingHitPrizeMapper groupBuyingHitPrizeMapper;

    @Autowired
    private GroupBuyingOrderMapper groupBuyingOrderMapper;

    @Autowired
    private IWalletService walletService;


    /**
     * 根据参数查询用户订单记录
     * @param GroupBuyingOrderParam
     * @return
     */
    @Override
    public List<GroupBuyingOrder> selectUserOrder(GroupBuyingOrderParam GroupBuyingOrderParam) {
        List<GroupBuyingOrder> userOrderRecords = groupBuyingOrderMapper.selectUserOrder(GroupBuyingOrderParam);
        return userOrderRecords;
    }


    /**
     * 经销商取消订单
     * @param GroupBuyingOrderParam
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public String cancelOrderByAdmin(GroupBuyingOrderParam GroupBuyingOrderParam) {
        //根据订单号查询订单信息
        String orderId = GroupBuyingOrderParam.getOrderId();
        if(StringUtils.isEmpty(orderId)) throw new ServiceException("订单号不能为空！");
        GroupBuyingOrder groupBuyingOrder = groupBuyingOrderMapper.selectById(orderId);
        if (Objects.isNull(groupBuyingOrder)) {
            throw new ServiceException("订单不存在");
        }
        if (!ChannelOrderStatusEnum.NOT_DELIVER.equals(groupBuyingOrder.getStatus())) {
            throw new ServiceException("订单状态异常，不能取消");
        }

        // 更新订单状态
        GroupBuyingOrder groupBuyingOrderParam  = new GroupBuyingOrder();
        groupBuyingOrderParam.setOrderId(groupBuyingOrder.getOrderId());
        groupBuyingOrderParam.setStatus(ChannelOrderStatusEnum.CANCELED.getValue());
        this.updateById(groupBuyingOrderParam);

        // 更新销量
        /*List<ChannelOrderItem> list = channelOrderItemService.list(new LambdaQueryWrapper<ChannelOrderItem>().eq(ChannelOrderItem::getOrderId, param.getOrderId()));
        if (CollectionUtils.isEmpty(list)) {
            throw new ServiceException("订单商品不存在");
        }
        for (ChannelOrderItem channelOrderItem : list) {
            TicketBox ticketBox = ticketBoxService.getById(channelOrderItem.getBoxId());

            boolean rst = this.rollbackTicketStatusAndSalePkgQty(channelOrderItem, ticketBox);
            if (!rst) {
                throw new ServiceException("操作繁忙,请稍后再试!");
            }
        }*/


        //退款
        walletService.refund(groupBuyingOrder.getOrderId(), groupBuyingOrder.getPayAmt(),"经销商取消订单");


        return null;
    }



}
